from bake_forecast.forecast import get_average_bakes
from pathlib import Path
import pytest


def test_valid_csv(tmp_path: Path):
    file = tmp_path / "data.csv"
    file.write_text("day;quantity_sold\nMonday;10\nMonday;20\nTuesday;5\n")

    from unittest.mock import patch

    with patch("bake_forecast.forecast.datetime") as mock_dt:
        mock_dt.today.return_value.strftime.return_value = "Monday"
        result = get_average_bakes(file)

    assert result == 15.0  # (10 + 20) / 2


def test_empty_csv(tmp_path: Path):
    empty_file = tmp_path / "empty.csv"
    empty_file.write_text("day;quantity_sold\n")

    from unittest.mock import patch

    with patch("bake_forecast.forecast.datetime") as mock_dt:
        mock_dt.today.return_value.strftime.return_value = "Thirsday"
        empty_result = get_average_bakes(empty_file)

    assert empty_result == 0.0


def test_file_not_found():
    with pytest.raises(FileNotFoundError):
        get_average_bakes(Path("non_existent.csv"))



import logging
import click
from pathlib import Path

from .forecast import get_average_bakes

logging.basicConfig(
    level=logging.INFO,
    format="[%(asctime)s] %(levelname)-8s %(name)s: %(message)s",
    datefmt="%Y-%m-%d %H:%M:%S",
)

logger = logging.getLogger(__name__)


@click.command()
@click.argument("file")
@click.option("--verbose", "-v", is_flag=True, help="Enable debug logging.")
def main(file: str, verbose: bool):
    file_path = Path(file)

    if verbose:
        logging.getLogger().setLevel(logging.DEBUG)
        logger.debug("Verbose logging enabled.")

    # Validate input
    if not file:
        logger.warning("No file path was provided.")
        click.echo("Usage: get_average_bakes <file_path>")
        return

    if not file_path.is_file():
        logger.warning("File not found error.")
        click.echo("Double check file path.")
        return

    logger.debug(f"Received verbose flag: {verbose}")
    logger.debug(f"Received file path: {file_path}")

    logger.info(f"Starting processing file '{file_path.name}'")

    result = get_average_bakes(file_path)

    click.echo("\n --RESULT--")
    logger.debug("Process finished with success.")
    click.echo(
        f"Recommended number of cookies to bake today is: {result:.1f}. Based on: {file_path}"
    )



import csv
from typing import Any
from datetime import datetime
from pathlib import Path


def get_average_bakes(file: str | Path) -> float:
    data_dict: dict[Any, Any] = {}
    file_path = Path(file)

    if not file_path.is_file():
        raise FileNotFoundError(f"File not found: {file_path}")

    # Read the content
    with open(file_path, encoding="utf-8") as csvfile:
        reader = csv.reader(csvfile, delimiter=";")
        next(reader)  # skip header
        for i, row in enumerate(reader, start=1):
            try:
                data_dict[i] = {"day": row[0], "quantity_sold": int(row[1])}
            except IndexError:
                pass

    today_day = datetime.today().strftime("%A")  # ex. Monday / Tuesday... /

    # Select only those that match today’s date
    quantities_today = [
        record["quantity_sold"]
        for record in data_dict.values()
        if record["day"] == today_day
    ]

    if quantities_today:
        average_today = sum(quantities_today) / len(quantities_today)
    else:
        print(f"Some error occured or no historical data for {today_day}")
        return 0.0

    return average_today
